@@ -1,39 +1,29 @@
 # -*- coding: utf-8 -*-
 
-#...............................licence...........................................
-#
-#     (C) Copyright 2008 Telefonica Investigacion y Desarrollo
-#     S.A.Unipersonal (Telefonica I+D)
-#
-#     This file is part of Morfeo EzWeb Platform.
-#
-#     Morfeo EzWeb Platform is free software: you can redistribute it and/or modify
-#     it under the terms of the GNU Affero General Public License as published by
-#     the Free Software Foundation, either version 3 of the License, or
-#     (at your option) any later version.
-#
-#     Morfeo EzWeb Platform is distributed in the hope that it will be useful,
-#     but WITHOUT ANY WARRANTY; without even the implied warranty of
-#     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#     GNU Affero General Public License for more details.
-#
-#     You should have received a copy of the GNU Affero General Public License
-#     along with Morfeo EzWeb Platform.  If not, see <http://www.gnu.org/licenses/>.
-#
-#     Info about members and contributors of the MORFEO project
-#     is available at
-#
-#     http://morfeo-project.org
-#
-#...............................licence...........................................#
+# Copyright (c) 2011-2014 CoNWeT Lab., Universidad Politécnica de Madrid
 
+# This file is part of Wirecloud.
 
-#
+# Wirecloud is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Affero General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
 
+# Wirecloud is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Affero General Public License for more details.
+
+# You should have received a copy of the GNU Affero General Public License
+# along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
+
+import random
 from urlparse import urlparse
 
+from django.core.cache import cache
 from django.db import models
 from django.contrib.auth.models import User, Group
+from django.utils.encoding import python_2_unicode_compatible
 from django.utils.translation import ugettext_lazy as _
 
 from wirecloud.commons.models import TransModel
@@ -41,6 +31,7 @@ from wirecloud.commons.utils.http import get_absolute_reverse_url
 from wirecloud.commons.utils.template.parsers import TemplateParser
 
 
+@python_2_unicode_compatible
 class CatalogueResource(TransModel):
 
     RESOURCE_TYPES = ('widget', 'mashup', 'operator')
@@ -56,7 +47,6 @@ class CatalogueResource(TransModel):
     vendor = models.CharField(_('Vendor'), max_length=250)
     version = models.CharField(_('Version'), max_length=150)
     type = models.SmallIntegerField(_('Type'), choices=TYPE_CHOICES, null=False, blank=False)
-    ie_compatible = models.BooleanField(_('IE Compatible'), default=False)
 
     author = models.CharField(_('Author'), max_length=250)
     mail = models.CharField(_('Mail'), max_length=100)
@@ -86,6 +76,15 @@ class CatalogueResource(TransModel):
 
         return self.vendor + '/' + self.short_name + '/' + self.version
 
+    @property
+    def cache_version(self):
+        version = cache.get('_catalogue_resource_version/' + str(self.id))
+        if version is None:
+            version = random.randrange(1, 100000)
+            cache.set('_catalogue_resource_version/' + str(self.id), version)
+
+        return version
+
     def is_available_for(self, user):
 
         return self.public or self.users.filter(id=user.id).exists() or len(set(self.groups.all()) & set(user.groups.all())) > 0
@@ -93,7 +92,7 @@ class CatalogueResource(TransModel):
     def get_template(self, request=None):
 
         if urlparse(self.template_uri).scheme == '':
-            template_uri = get_absolute_reverse_url('wirecloud_showcase.media', kwargs={
+            template_uri = get_absolute_reverse_url('wirecloud.showcase_media', kwargs={
                 'vendor': self.vendor,
                 'name': self.short_name,
                 'version': self.version,
@@ -118,12 +117,6 @@ class CatalogueResource(TransModel):
         # Delete the related wiring information for that resource
         WidgetWiring.objects.filter(idResource=self.id).delete()
 
-        # Delete the related tags for that resource
-        UserTag.objects.filter(idResource=self.id).delete()
-
-        # Delete the related votes for that resource
-        UserVote.objects.filter(idResource=self.id).delete()
-
         if hasattr(self, 'widget'):
             from wirecloud.platform.models import Widget
             try:
@@ -135,8 +128,15 @@ class CatalogueResource(TransModel):
         if not self.template_uri.startswith(('http', 'https')):
             wgt_deployer.undeploy(self.vendor, self.short_name, self.version)
 
+        old_id = self.id
         super(CatalogueResource, self).delete(*args, **kwargs)
 
+        # Remove cache for this resource
+        try:
+            cache.incr('_catalogue_resource_version/' + str(old_id))
+        except ValueError:
+            pass
+
     def resource_type(self):
         return self.RESOURCE_TYPES[self.type]
 
@@ -147,75 +147,16 @@ class CatalogueResource(TransModel):
     class Meta:
         unique_together = ("short_name", "vendor", "version")
 
-    def __unicode__(self):
-        return unicode(self.local_uri_part)
+    def __str__(self):
+        return self.local_uri_part
 
 
+@python_2_unicode_compatible
 class WidgetWiring(models.Model):
 
     friendcode = models.CharField(_('Friend code'), max_length=30, blank=True, null=True)
     wiring = models.CharField(_('Wiring'), max_length=5)
     idResource = models.ForeignKey(CatalogueResource)
 
-    def __unicode__(self):
-        return unicode(self.friendcode)
-
-
-class Tag(models.Model):
-
-    name = models.CharField(max_length=20, unique=True)
-
-    def __unicode__(self):
-        return unicode(self.name)
-
-
-class UserTag(models.Model):
-
-    tag = models.ForeignKey(Tag)
-    weight = models.CharField(max_length=20, null=True)
-    criteria = models.CharField(max_length=20, null=True)
-    value = models.CharField(max_length=20, null=True)
-    idUser = models.ForeignKey(User)
-    idResource = models.ForeignKey(CatalogueResource)
-
-    class Meta:
-        unique_together = ("tag", "idUser", "idResource")
-
-    #def __unicode__(self):
-    #   return self.tag
-
-
-class Category(TransModel):
-
-    name = models.CharField(max_length=50, unique=True)
-    tags = models.ManyToManyField(Tag)
-    parent = models.ForeignKey('self', blank=True, null=True)
-    organizations = models.ManyToManyField(Group, related_name='organizations', null=True, blank=True)
-
-    def __unicode__(self):
-        return self.name
-
-VOTES = (
-    (u'0', 0),
-    (u'1', 1),
-    (u'1', 2),
-    (u'1', 3),
-    (u'1', 4),
-    (u'1', 5),
-)
-
-
-class UserVote(models.Model):
-    """
-    A vote on a CatalogueResource by a User.
-    """
-    idUser = models.ForeignKey(User)
-    idResource = models.ForeignKey(CatalogueResource)
-    vote = models.SmallIntegerField(choices=VOTES)
-
-    class Meta:
-        # One vote per user per object
-        unique_together = (('idUser', 'idResource'),)
-
-    def __unicode__(self):
-        return u'%s: %s on %s' % (self.idUser, self.vote, self.idResource)
+    def __str__(self):
+        return self.friendcode
