@@ -1,5 +1,5 @@
 /*
- *     (C) Copyright 2012 Universidad Politécnica de Madrid
+ *     Copyright 2012-2013 (c) CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -19,7 +19,7 @@
  *
  */
 
-/*global Constants, Element, EzWebExt, gettext, interpolate, LayoutManagerFactory, LogManagerFactory, StyledElements, Wirecloud*/
+/*global gettext, interpolate, LayoutManagerFactory, StyledElements, Wirecloud*/
 
 (function () {
 
@@ -32,8 +32,9 @@
      *************************************************************************/
 
     upload_wgt_file = function upload_wgt_file() {
-        LayoutManagerFactory.getInstance()._startComplexTask(gettext("Uploading packaged widget"), 1);
+        var monitor = LayoutManagerFactory.getInstance()._startComplexTask(gettext("Uploading packaged widget"), 1);
         this.catalogue.addPackagedResource(new FormData(this.wrapperElement.getElementsByClassName("wgt_upload_form")[0]), {
+            monitor: monitor,
             onSuccess: this._onUploadSuccess.bind(this),
             onFailure: this._onUploadFailure.bind(this)
         });
@@ -55,7 +56,7 @@
                 this.mainview.refresh_search_results();
             }.bind(this),
             onFailure: function (msg) {
-                LayoutManagerFactory.getInstance().showMessageMenu(msg, Constants.Logging.ERROR_MSG);
+                (new Wirecloud.ui.MessageWindowMenu(msg, Wirecloud.constants.LOGGING.ERROR_MSG)).show();
             },
             onComplete: function () {
                 LayoutManagerFactory.getInstance()._notifyPlatformReady();
@@ -103,8 +104,6 @@
     PublishView.prototype._onUploadSuccess = function _onUploadSuccess() {
         var layoutManager = LayoutManagerFactory.getInstance();
 
-        layoutManager.logSubTask(gettext('Resource uploaded successfully'));
-        layoutManager.logStep('');
         layoutManager._notifyPlatformReady();
 
         this.mainview.home();
@@ -115,7 +114,7 @@
         var layoutManager = LayoutManagerFactory.getInstance();
 
         layoutManager._notifyPlatformReady();
-        layoutManager.showMessageMenu(msg, Constants.Logging.ERROR_MSG);
+        (new Wirecloud.ui.MessageWindowMenu(msg, Wirecloud.constants.LOGGING.ERROR_MSG)).show();
     };
 
     Wirecloud.ui.WirecloudCatalogue = {};
