@@ -1,20 +1,20 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012-2013 Universidad Politécnica de Madrid
+# Copyright (c) 2012-2014 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
 # Wirecloud is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
+# it under the terms of the GNU Affero General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 
 # Wirecloud is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
 import json
@@ -39,7 +39,7 @@ def get_xml_error_response(request, mimetype, status_code, context):
     doc = etree.Element('error')
 
     description = etree.Element('description')
-    description.text = context['error_msg']
+    description.text = unicode(context['error_msg'])
 
     doc.append(description)
 
@@ -47,27 +47,35 @@ def get_xml_error_response(request, mimetype, status_code, context):
         details_element = etree.Element('details')
         for key in context['details']:
             element = etree.Element(key)
+
             if isinstance(context['details'][key], basestring):
                 element.text = context['details'][key]
+            elif hasattr(context['details'][key], '__iter__'):
+                for value in context['details'][key]:
+                    list_element = etree.Element('element')
+                    list_element.text = value
+                    element.append(list_element)
             else:
                 for key2 in context['details'][key]:
-                    list_element = etree.Element('element')
+                    list_element = etree.Element(key2)
                     list_element.text = context['details'][key][key2]
                     element.append(list_element)
 
             details_element.append(element)
 
+        doc.append(details_element)
+
     return etree.tostring(doc, pretty_print=False, method='xml')
 
 
 def get_json_error_response(request, mimetype, status_code, context):
     body = {
-        'description': context['error_msg']
+        'description': unicode(context['error_msg'])
     }
     if context.get('details') is not None:
         body['details'] = context['details']
 
-    return json.dumps(body)
+    return json.dumps(body, ensure_ascii=False)
 
 
 def get_plain_text_error_response(request, mimetype, status_code, context):
@@ -77,6 +85,8 @@ def get_plain_text_error_response(request, mimetype, status_code, context):
 ERROR_FORMATTERS = {
     'application/json; charset=utf-8': get_json_error_response,
     'application/xml; charset=utf-8': get_xml_error_response,
+    'text/html; charset=utf-8': get_html_basic_error_response,
+    'application/xhtml+xml; charset=utf-8': get_html_basic_error_response,
     'text/plain; charset=utf-8': get_plain_text_error_response,
     '': get_plain_text_error_response,   # Fallback
 }
@@ -84,19 +94,19 @@ ERROR_FORMATTERS = {
 def build_response(request, status_code, context, formatters, headers):
 
     if request.META.get('HTTP_X_REQUESTED_WITH', '') == 'XMLHttpRequest':
-        mimetype = 'application/json; charset=utf-8'
+        content_type = 'application/json; charset=utf-8'
     else:
         formatter_keys = formatters.keys()
         formatter_keys.remove('')
-        mimetype = mimeparser.best_match(formatter_keys, request.META.get('HTTP_ACCEPT', '*/*'))
+        content_type = mimeparser.best_match(formatter_keys, request.META.get('HTTP_ACCEPT', '*/*'))
 
-    if mimetype in formatters:
-        formatter = formatters[mimetype]
+    if content_type in formatters:
+        formatter = formatters[content_type]
     else:
         raise Exception('No suitable formatter found')
 
-    body = formatter(request, mimetype, status_code, context)
-    response = HttpResponse(body, mimetype=mimetype, status=status_code)
+    body = formatter(request, content_type, status_code, context)
+    response = HttpResponse(body, content_type=content_type, status=status_code)
     if headers is None:
         headers = {}
 
@@ -143,10 +153,7 @@ def authentication_required(func):
         if request.user.is_anonymous():
             from django.conf import settings
 
-            return build_error_response(request, 401, 'Authentication required', extra_formats={
-                'text/html; charset=utf-8': get_html_basic_error_response,
-                'application/xhtml+xml; charset=utf-8': get_html_basic_error_response,
-            }, headers={
+            return build_error_response(request, 401, 'Authentication required', headers={
                 'WWW-Authenticate': 'Cookie realm="Acme" form-action="%s" cookie-name="%s"' % (settings.LOGIN_URL, settings.SESSION_COOKIE_NAME)
             })
 
@@ -155,6 +162,18 @@ def authentication_required(func):
     return wrapper
 
 
+def authentication_required_cond(cond):
+
+    def wrap(func):
+
+        if cond is True:
+            return func
+        else:
+            return authentication_required(func)
+
+    return wrap
+
+
 def supported_response_mime_types(mime_types):
 
     def wrap(func):
