@@ -17,9 +17,12 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import unicode_literals
+
 import rdflib
 
 from django.utils.translation import ugettext as _
+from lxml import etree
 
 from wirecloud.commons.utils.template.base import is_valid_name, is_valid_vendor, is_valid_version, TemplateParseException
 from wirecloud.commons.utils.http import parse_mime_type
@@ -30,7 +33,8 @@ WIRE_M = rdflib.Namespace("http://wirecloud.conwet.fi.upm.es/ns/mashup#")
 FOAF = rdflib.Namespace("http://xmlns.com/foaf/0.1/")
 USDL = rdflib.Namespace("http://www.linked-usdl.org/ns/usdl-core#")
 DCTERMS = rdflib.Namespace("http://purl.org/dc/terms/")
-RDF = rdflib.Namespace("http://www.w3.org/1999/02/22-rdf-syntax-ns#")
+RDF_NS = "http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+RDF = rdflib.Namespace(RDF_NS)
 RDFS = rdflib.Namespace("http://www.w3.org/2000/01/rdf-schema#")
 VCARD = rdflib.Namespace("http://www.w3.org/2006/vcard/ns#")
 BLUEPRINT = rdflib.Namespace("http://bizweb.sap.com/TR/blueprint#")
@@ -58,6 +62,24 @@ class RDFTemplateParser(object):
                 self._graph = rdflib.Graph()
                 self._graph.parse(data=template, format='n3')
             except:
+                if isinstance(template, str):
+                    doc = etree.fromstring(template)
+                elif isinstance(template, unicode):
+                    # Work around: ValueError: Unicode strings with encoding
+                    # declaration are not supported.
+                    doc = etree.fromstring(template.encode('utf-8'))
+
+                root_element_qname = etree.QName(doc)
+
+                if root_element_qname.namespace is None:
+                    raise TemplateParseException("XML document does not contain a valid rdf namespace")
+
+                if root_element_qname.namespace != RDF_NS:
+                    raise TemplateParseException("Invalid namespace: " + root_element_qname.namespace)
+
+                if root_element_qname.localname != 'RDF':
+                    raise TemplateParseException("Invalid root element: " + root_element_qname.localname)
+
                 self._graph = rdflib.Graph()
                 self._graph.parse(data=template, format='xml')
 
@@ -183,20 +205,25 @@ class RDFTemplateParser(object):
         if not is_valid_version(self._info['version']):
             raise TemplateParseException(_('ERROR: the format of the version number is invalid. Format: X.X.X where X is an integer. Ex. "0.1", "1.11" NOTE: "1.01" should be changed to "1.0.1" or "1.1"'))
 
+        license = self._get_field(DCTERMS, 'license', self._rootURI, required=False, default=None, id_=True)
+        if license is not None:
+            self._info['licenseurl'] = unicode(license)
+            self._info['license'] = self._get_field(RDFS, 'label', license, required=False)
+        else:
+            self._info['licenseurl'] = ''
+            self._info['license'] = ''
+
         self._info['description'] = self._get_translation_field(DCTERMS, 'description', self._rootURI, 'description', type='resource', field='description')
 
-        author = self._get_field(DCTERMS, 'creator', self._rootURI, id_=True)
-        self._info['author'] = self._get_field(FOAF, 'name', author)
+        authors = self._get_field(DCTERMS, 'creator', self._rootURI, required=False, id_=True)
+        self._info['authors'] = self._get_field(FOAF, 'name', authors, required=False)
 
-        self._info['image_uri'] = self._get_field(WIRE, 'hasImageUri', self._rootURI)
-        self._info['iphone_image_uri'] = self._get_field(WIRE, 'hasiPhoneImageUri', self._rootURI, required=False)
+        self._info['image'] = self._get_field(WIRE, 'hasImageUri', self._rootURI, required=False)
+        self._info['smartphoneimage'] = self._get_field(WIRE, 'hasiPhoneImageUri', self._rootURI, required=False)
 
-        self._info['doc_uri'] = self._get_field(FOAF, 'page', self._rootURI, required=False)
+        self._info['doc'] = self._get_field(FOAF, 'page', self._rootURI, required=False)
 
-        self._info['display_name'] = self._get_translation_field(WIRE, 'displayName', self._rootURI, 'display_name', required=False, type='resource', field='display_name')
-
-        if not self._info['display_name']:
-            self._info['display_name'] = self._info['name']
+        self._info['title'] = self._get_translation_field(WIRE, 'displayName', self._rootURI, 'title', required=False, type='resource', field='title')
 
         addr_element = self._get_field(VCARD, 'addr', self._rootURI, id_=True)
         self._info['email'] = self._get_field(VCARD, 'email', addr_element)
@@ -376,7 +403,7 @@ class RDFTemplateParser(object):
                 'label': self._get_translation_field(RDFS, 'label', preference, var_name + '_label', required=False, type='vdef', variable=var_name, field='label'),
                 'description': self._get_translation_field(DCTERMS, 'description', preference, var_name + '_description', required=False, type='vdef', variable=var_name, field='description'),
                 'readonly': self._get_field(WIRE, 'readonly', preference, required=False).lower() == 'true',
-                'default_value': self._get_field(WIRE, 'default', preference, required=False),
+                'default': self._get_field(WIRE, 'default', preference, required=False),
                 'value': self._get_field(WIRE, 'value', preference, required=False, default=None),
                 'secure': self._get_field(WIRE, 'secure', preference, required=False).lower() == 'true',
             }
@@ -403,14 +430,12 @@ class RDFTemplateParser(object):
                 'type': self._get_field(WIRE, 'type', prop, required=False),
                 'label': self._get_translation_field(RDFS, 'label', prop, var_name + '_label', required=False, type='vdef', variable=var_name, field='label'),
                 'description': self._get_translation_field(DCTERMS, 'description', prop, var_name + '_description', required=False, type='vdef', variable=var_name, field='description'),
-                'default_value': self._get_field(WIRE, 'default', prop, required=False),
+                'default': self._get_field(WIRE, 'default', prop, required=False),
                 'secure': self._get_field(WIRE, 'secure', prop, required=False).lower() == 'true',
             })
 
         self._parse_wiring_info()
 
-        self._info['context'] = []
-
         if self._info['type'] == 'widget':
             # It contains the widget code
             xhtml_element = self._get_field(USDL, 'utilizedResource', self._rootURI, id_=True)
@@ -547,7 +572,7 @@ class RDFTemplateParser(object):
         if typeText in mapping:
             return mapping[typeText]
         else:
-            raise TemplateParseException(_(u"ERROR: unkown TEXT TYPE ") + typeText)
+            raise TemplateParseException(_("ERROR: unkown TEXT TYPE ") + typeText)
 
     def get_contents(self):
         return self._graph.serialize(format='pretty-xml')
