@@ -36,22 +36,6 @@ class WgtFile(object):
 
     def __init__(self, _file):
         self._zip = zipfile.ZipFile(_file)
-        self._parse_config_file()
-
-    def _parse_config_file(self):
-
-        config = self._zip.read('config.xml')
-        try:
-            doc = etree.fromstring(config)
-            prefix = doc.prefix
-            xmlns = None
-            if prefix in doc.nsmap:
-                xmlns = doc.nsmap[prefix]
-
-            if xmlns == 'http://www.w3.org/ns/widgets/':
-                self._template_filename = doc.get('id')
-        except:
-            pass
 
     def get_underlying_file(self):
         return self._zip.fp
@@ -60,7 +44,10 @@ class WgtFile(object):
         return self._zip.read(path)
 
     def get_template(self):
-        return self.read(self._template_filename)
+        try:
+            return self.read(self._template_filename)
+        except KeyError:
+            raise InvalidContents('Missing config.xml at the root of the zipfile (wgt)')
 
     def extract_file(self, file_name, output_path, recreate_=False):
         contents = self.read(file_name)
