@@ -19,7 +19,7 @@
  *
  */
 
-/*global Event, OpManagerFactory, StyledElements, gettext, interpolate, LayoutManagerFactory, CatalogueSearchView, FiWareResourceDetailsView, FiWareCatalogue, Wirecloud, FiWareCatalogueResource, FiWareStoreListItems*/
+/*global OpManagerFactory, StyledElements, gettext, interpolate, LayoutManagerFactory, CatalogueSearchView, Wirecloud, FiWareCatalogueResource*/
 
 (function () {
 
@@ -70,7 +70,9 @@
         this.error = false;
         this.store_info = [];
 
-        this.storeSelect = new StyledElements.StyledSelect();
+        this.storeSelect = new StyledElements.StyledSelect({
+            'class': 'store_select'
+        });
         this.storeSelect.addEventListener('change', change_store_filter.bind(this));
         search_view_options = {
             catalogue: this,
@@ -126,14 +128,9 @@
     };
 
     FiWareCatalogueView.prototype._onSearch = function (callback, raw_data) {
-        var preferred_versions, i, data, resources, resource;
+        var i, data, resources, resource;
 
         if (raw_data.resources) {
-            preferred_versions = Wirecloud.utils.CookieManager.readCookie('preferred_versions', true);
-
-            if (preferred_versions === null) {
-                preferred_versions = {};
-            }
 
             resources = [];
 
@@ -144,7 +141,6 @@
 
             data = {
                 'resources': resources,
-                'preferred_versions': preferred_versions,
                 'query_results_number': resources.length,
                 'resources_per_page': 10,
                 'current_page': 1
@@ -154,16 +150,6 @@
         }
     };
 
-    FiWareCatalogueView.prototype.instantiate = function (resource) {
-        //is mashup?
-        if (resource.isMashup()) {
-            (new Wirecloud.ui.InstantiateMashupWindowMenu(resource)).show();
-        } else {
-            var local_widget = Wirecloud.LocalCatalogue.getResourceId(resource.getURI());
-            OpManagerFactory.getInstance().addInstance(local_widget);
-        }
-    };
-
     FiWareCatalogueView.prototype.getPublishEndpoints = function getPublishEndpoints() {
         var i, stores = [];
 
@@ -231,7 +217,7 @@
     FiWareCatalogueView.prototype.ui_commands = {};
 
     FiWareCatalogueView.prototype.ui_commands.instantiate = function (resource) {
-        return function (e) {
+        return function () {
             this.instantiate(resource);
             LayoutManagerFactory.getInstance().changeCurrentView('workspace');
         }.bind(this);
@@ -275,5 +261,5 @@
 
     Wirecloud.FiWare.FiWareCatalogueView = FiWareCatalogueView;
 
-    Wirecloud.MarketManager.addMarketType('fiware', 'FiWare', FiWareCatalogueView);
+    Wirecloud.MarketManager.addMarketType('fiware', 'FI-WARE', FiWareCatalogueView);
 })();
