@@ -38,7 +38,7 @@ from django.utils.translation import ugettext as _
 
 from wirecloud.commons.utils.cache import CacheableData
 from wirecloud.commons.utils.encoding import LazyEncoder
-from wirecloud.platform.models import IWidget, PublishedWorkspace, Tab, UserWorkspace, Variable, VariableValue
+from wirecloud.platform.models import IWidget, Tab, UserWorkspace, Variable
 from wirecloud.platform.context.utils import get_workspace_context, get_context_values
 from wirecloud.platform.preferences.views import get_workspace_preference_values, get_tab_preference_values
 from wirecloud.platform.workspace.utils import createTab, decrypt_value, encrypt_value
@@ -71,16 +71,15 @@ def _populate_variables_values_cache(workspace, user, key, forced_values=None):
     values_by_varid = {}
     values_by_varname = {}
 
-    if forced_values == None:
-        user_workspace = UserWorkspace.objects.get(user=user, workspace=workspace)
-        context_values = get_context_values(user_workspace)
+    if forced_values is None:
+        context_values = get_context_values(workspace, user)
         preferences = get_workspace_preference_values(workspace)
         forced_values = process_forced_values(workspace, user, context_values, preferences)
 
-    var_values = VariableValue.objects.filter(user__id=user.id, variable__iwidget__tab__workspace=workspace)
-    for var_value in var_values.select_related('variable__vardef'):
-        variwidget = var_value.variable.iwidget.id
-        varname = var_value.variable.vardef.name
+    var_values = Variable.objects.filter(iwidget__tab__workspace=workspace)
+    for variable in var_values.select_related('vardef'):
+        variwidget = variable.iwidget.id
+        varname = variable.vardef.name
         # forced_values uses string keys
         svariwidget = str(variwidget)
 
@@ -92,23 +91,23 @@ def _populate_variables_values_cache(workspace, user, key, forced_values=None):
             fv_entry = forced_values['iwidget'][svariwidget][varname]
 
             entry['value'] = fv_entry['value']
-            if var_value.variable.vardef.secure:
+            if variable.vardef.secure:
                 entry['value'] = encrypt_value(entry['value'])
 
             entry['readonly'] = True
             entry['hidden'] = fv_entry.get('hidden', False)
 
         else:
-            entry['value'] = var_value.value
+            entry['value'] = variable.value
 
             entry['readonly'] = False
             entry['hidden'] = False
 
-        entry['type'] = var_value.variable.vardef.type
-        entry['secure'] = var_value.variable.vardef.secure
+        entry['type'] = variable.vardef.type
+        entry['secure'] = variable.vardef.secure
 
         values_by_varname[variwidget][varname] = entry
-        values_by_varid[var_value.variable.id] = entry
+        values_by_varid[variable.id] = entry
 
     values = {
         'by_varid': values_by_varid,
@@ -208,11 +207,6 @@ class VariableValueCacheManager():
 
         return self.values
 
-    def get_variable_value_from_var(self, variable):
-        values = self.get_variable_values()
-        entry = values['by_varid'][variable.id]
-        return self._process_entry(entry)
-
     def get_variable_value_from_varname(self, iwidget, var_name):
 
         if 'id' in iwidget:
@@ -254,7 +248,14 @@ class VariableValueCacheManager():
 
 
 def get_workspace_data(workspace, user):
-    user_workspace = UserWorkspace.objects.get(user=user, workspace=workspace)
+
+    user_workspace = None
+
+    if user.is_authenticated():
+        try:
+            user_workspace = UserWorkspace.objects.get(user=user, workspace=workspace)
+        except UserWorkspace.DoesNotExist:
+            pass
 
     return {
         'id': workspace.id,
@@ -262,8 +263,8 @@ def get_workspace_data(workspace, user):
         'shared': workspace.is_shared(),
         'creator': workspace.creator.username,
         'owned': workspace.creator == user,
-        'removable': workspace.creator == user and user_workspace.manager == '',
-        'active': user_workspace.active,
+        'removable': workspace.creator == user and (user_workspace is None or user_workspace.manager == ''),
+        'active': user_workspace is not None and user_workspace.active,
     }
 
 
@@ -352,18 +353,17 @@ def process_forced_values(workspace, user, concept_values, preferences):
 
 
 def _get_global_workspace_data(workspaceDAO, user):
-    user_workspace = UserWorkspace.objects.get(user=user, workspace=workspaceDAO)
     data_ret = get_workspace_data(workspaceDAO, user)
 
     # Context information
-    data_ret['context'] = get_workspace_context(user_workspace)
+    data_ret['context'] = get_workspace_context(workspaceDAO, user)
 
     # Workspace preferences
     preferences = get_workspace_preference_values(workspaceDAO.pk)
     data_ret['preferences'] = preferences
 
     # Process forced variable values
-    concept_values = get_context_values(user_workspace)
+    concept_values = get_context_values(workspaceDAO, user)
     forced_values = process_forced_values(workspaceDAO, user, concept_values, preferences)
     data_ret['empty_params'] = forced_values['empty_params']
     data_ret['extra_prefs'] = forced_values['extra_prefs']
@@ -396,7 +396,7 @@ def _get_global_workspace_data(workspaceDAO, user):
 
         iwidget_data = []
         for iwidget in iwidgets:
-            iwidget_data.append(get_iwidget_data(iwidget, user, workspaceDAO, cache_manager))
+            iwidget_data.append(get_iwidget_data(iwidget, workspaceDAO, cache_manager))
 
         tab['iwidgets'] = iwidget_data
 
@@ -405,11 +405,6 @@ def _get_global_workspace_data(workspaceDAO, user):
         for forced_pref_name, forced_preference in forced_preferences.iteritems():
             data_ret['wiring']['operators'][forced_operator_id]['preferences'][forced_pref_name]['value'] = forced_preference['value']
 
-    # Params
-    last_published_workspace = PublishedWorkspace.objects.filter(workspace=workspaceDAO).order_by('-pk')
-    if len(last_published_workspace) > 0:
-        data_ret["params"] = json.loads(last_published_workspace[0].params)
-
     return json.dumps(data_ret, cls=LazyEncoder)
 
 
@@ -418,6 +413,7 @@ def get_global_workspace_data(workspace, user):
     data = cache.get(key)
     if data is None:
         data = CacheableData(_get_global_workspace_data(workspace, user))
+        key = _workspace_cache_key(workspace, user)
         cache.set(key, data)
 
     return data
@@ -432,7 +428,7 @@ def get_tab_data(tab):
     }
 
 
-def get_iwidget_data(iwidget, user, workspace, cache_manager=None):
+def get_iwidget_data(iwidget, workspace, cache_manager=None, user=None):
 
     data_ret = {'id': iwidget.id,
         'name': iwidget.name,
@@ -457,19 +453,19 @@ def get_iwidget_data(iwidget, user, workspace, cache_manager=None):
         data_ret['icon_top'] = 0
         data_ret['icon_left'] = 0
 
-    if cache_manager == None:
+    if cache_manager is None:
         cache_manager = VariableValueCacheManager(workspace, user)
 
     variables = _get_cached_variables(iwidget)
     data_ret['variables'] = {}
     for variable in variables:
-        var_data = get_variable_data(variable, user, workspace, cache_manager)
+        var_data = get_variable_data(variable, workspace, cache_manager)
         data_ret['variables'][variable.vardef.name] = var_data
 
     return data_ret
 
 
-def get_variable_data(variable, user, workspace, cache_manager=None):
+def get_variable_data(variable, workspace, cache_manager=None, user=None):
     data_ret = {
         'id': variable.id,
         'name': variable.vardef.name,
@@ -478,7 +474,7 @@ def get_variable_data(variable, user, workspace, cache_manager=None):
     if variable.vardef.aspect != 'PREF' and variable.vardef.aspect != 'PROP':
         return data_ret
 
-    if cache_manager == None:
+    if cache_manager is None:
         cache_manager = VariableValueCacheManager(workspace, user)
 
     # Variable info is splited into 2 entities: VariableDef and VariableValue
