@@ -1,29 +1,29 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012-2013 Universidad Politécnica de Madrid
+# Copyright (c) 2012-2013 CoNWeT Lab., Universidad Politécnica de Madrid
 
-# This file is part of Wirecluod.
+# This file is part of Wirecloud.
 
 # Wirecloud is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
+# it under the terms of the GNU Affero General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 
 # Wirecloud is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
-
 import json
 
 from django.http import HttpResponse
 from django.utils.translation import ugettext as _
 from django.shortcuts import get_object_or_404
 
+from wirecloud.catalogue.models import CatalogueResource
 from wirecloud.commons.baseviews import Resource
 from wirecloud.commons.exceptions import Http403
 from wirecloud.commons.utils.cache import no_cache
@@ -31,7 +31,7 @@ from wirecloud.commons.utils.transaction import commit_on_http_success
 from wirecloud.commons.utils.http import authentication_required, build_error_response, supported_request_mime_types
 from wirecloud.platform.get_data import VariableValueCacheManager, get_iwidget_data
 from wirecloud.platform.iwidget.utils import SaveIWidget, UpdateIWidget, UpgradeIWidget
-from wirecloud.platform.models import Widget, IWidget, Tab, UserWorkspace, VariableValue, Workspace
+from wirecloud.platform.models import Widget, IWidget, Tab, UserWorkspace, Variable, Workspace
 from wirecloud.platform.widget.utils import get_or_add_widget_from_catalogue
 
 
@@ -45,9 +45,9 @@ class IWidgetCollection(Resource):
 
         cache_manager = VariableValueCacheManager(workspace, request.user)
         iwidgets = IWidget.objects.filter(tab__workspace__users=request.user, tab__workspace__pk=workspace_id, tab__pk=tab_id)
-        data = [get_iwidget_data(iwidget, request.user, workspace, cache_manager) for iwidget in iwidgets]
+        data = [get_iwidget_data(iwidget, workspace, cache_manager) for iwidget in iwidgets]
 
-        return HttpResponse(json.dumps(data), mimetype='application/json; charset=UTF-8')
+        return HttpResponse(json.dumps(data), content_type='application/json; charset=UTF-8')
 
     @authentication_required
     @supported_request_mime_types(('application/json',))
@@ -55,8 +55,8 @@ class IWidgetCollection(Resource):
     def create(self, request, workspace_id, tab_id):
 
         try:
-            iwidget = json.loads(request.raw_post_data)
-        except ValueError, e:
+            iwidget = json.loads(request.body)
+        except ValueError as e:
             msg = _("malformed json data: %s") % unicode(e)
             return build_error_response(request, 400, msg)
 
@@ -64,18 +64,18 @@ class IWidgetCollection(Resource):
 
         # iWidget creation
         tab = get_object_or_404(Tab.objects.select_related('workspace'), workspace__pk=workspace_id, pk=tab_id)
-        if not request.user.is_superuser and not tab.workspace.users.filter(id=request.user.id).exists():
-            raise Http403
+        if not request.user.is_superuser and tab.workspace.creator != request.user:
+            msg = _('You have not enough permission for adding iwidgets to the workspace')
+            return build_error_response(request, 403, msg)
 
         try:
             iwidget = SaveIWidget(iwidget, request.user, tab, initial_variable_values)
-            iwidget_data = get_iwidget_data(iwidget, request.user, tab.workspace)
+            iwidget_data = get_iwidget_data(iwidget, tab.workspace, user=request.user)
 
-            return HttpResponse(json.dumps(iwidget_data), mimetype='application/json; charset=UTF-8')
-        except Widget.DoesNotExist, e:
+            return HttpResponse(json.dumps(iwidget_data), content_type='application/json; charset=UTF-8')
+        except (CatalogueResource.DoesNotExist, Widget.DoesNotExist) as e:
             msg = _('referred widget %(widget_uri)s does not exist.') % {'widget_uri': iwidget['widget']}
-
-            return build_error_response(request, 400, msg)
+            return build_error_response(request, 422, msg)
 
     @authentication_required
     @supported_request_mime_types(('application/json',))
@@ -83,12 +83,16 @@ class IWidgetCollection(Resource):
     def update(self, request, workspace_id, tab_id):
 
         try:
-            iwidgets = json.loads(request.raw_post_data)
-        except ValueError, e:
+            iwidgets = json.loads(request.body)
+        except ValueError as e:
             msg = _("malformed json data: %s") % unicode(e)
             return build_error_response(request, 400, msg)
 
         tab = get_object_or_404(Tab, workspace__users=request.user, workspace__pk=workspace_id, pk=tab_id)
+        if not request.user.is_superuser and tab.workspace.creator != request.user:
+            msg = _('You have not enough permission for updating the iwidgets of this workspace')
+            return build_error_response(request, 403, msg)
+
         for iwidget in iwidgets:
             UpdateIWidget(iwidget, request.user, tab)
 
@@ -104,9 +108,9 @@ class IWidgetEntry(Resource):
         workspace = get_object_or_404(Workspace, id=workspace_id)
 
         iwidget = get_object_or_404(IWidget, tab__workspace__users=request.user, tab__workspace=workspace, tab__pk=tab_id, pk=iwidget_id)
-        iwidget_data = get_iwidget_data(iwidget, request.user, workspace)
+        iwidget_data = get_iwidget_data(iwidget, workspace, user=request.user)
 
-        return HttpResponse(json.dumps(iwidget_data), mimetype='application/json; charset=UTF-8')
+        return HttpResponse(json.dumps(iwidget_data), content_type='application/json; charset=UTF-8')
 
     @authentication_required
     @supported_request_mime_types(('application/json',))
@@ -114,14 +118,15 @@ class IWidgetEntry(Resource):
     def create(self, request, workspace_id, tab_id, iwidget_id):
 
         try:
-            iwidget = json.loads(request.raw_post_data)
-        except ValueError, e:
+            iwidget = json.loads(request.body)
+        except ValueError as e:
             msg = _("malformed json data: %s") % unicode(e)
             return build_error_response(request, 400, msg)
 
         tab = get_object_or_404(Tab.objects.select_related('workspace'), workspace__pk=workspace_id, pk=tab_id)
-        if not request.user.is_superuser and not tab.workspace.users.filter(id=request.user.id).exists():
-            raise Http403
+        if not request.user.is_superuser and tab.workspace.creator != request.user:
+            msg = _('You have not enough permission for updating the iwidget')
+            return build_error_response(request, 403, msg)
 
         iwidget['id'] = iwidget_id
         UpdateIWidget(iwidget, request.user, tab)
@@ -134,8 +139,13 @@ class IWidgetEntry(Resource):
 
         # Gets Iwidget, if it does not exist, a http 404 error is returned
         iwidget = get_object_or_404(IWidget.objects.select_related('tab__workspace'), tab__workspace__pk=workspace_id, tab__pk=tab_id, pk=iwidget_id)
-        if not request.user.is_superuser and not iwidget.tab.workspace.users.filter(id=request.user.id).exists():
-            raise Http403
+        if not request.user.is_superuser and iwidget.tab.workspace.creator != request.user:
+            msg = _('You have not enough permission for removing iwidgets from the workspace')
+            return build_error_response(request, 403, msg)
+
+        if iwidget.readOnly:
+            msg = _('IWidget cannot be deleted')
+            return build_error_response(request, 403, msg)
 
         iwidget.delete()
 
@@ -150,24 +160,24 @@ class IWidgetPreferences(Resource):
     def create(self, request, workspace_id, tab_id, iwidget_id):
 
         workspace = Workspace.objects.get(id=workspace_id)
-        if not request.user.is_superuser and not workspace.users.filter(id=request.user.id).exists():
-            raise Http403()
+        if not request.user.is_superuser and workspace.creator != request.user:
+            msg = _('You have not enough permission for updating the preferences of the iwidget')
+            return build_error_response(request, 403, msg)
 
         try:
-            new_values = json.loads(request.raw_post_data)
-        except ValueError, e:
+            new_values = json.loads(request.body)
+        except ValueError as e:
             msg = _("malformed json data: %s") % unicode(e)
             return build_error_response(request, 400, msg)
 
         for var_name in new_values:
-            variable_value = VariableValue.objects.select_related('variable__vardef').get(
-                user=request.user,
-                variable__vardef__name=var_name,
-                variable__vardef__aspect='PREF',
-                variable__iwidget__id=iwidget_id
+            variable = Variable.objects.select_related('vardef').get(
+                vardef__name=var_name,
+                vardef__aspect='PREF',
+                iwidget__id=iwidget_id
             )
-            variable_value.set_variable_value(new_values[var_name])
-            variable_value.save()
+            variable.set_variable_value(new_values[var_name])
+            variable.save()
 
         return HttpResponse(status=204)
 
@@ -184,8 +194,8 @@ class IWidgetVersion(Resource):
             raise Http403()
 
         try:
-            data = json.loads(request.raw_post_data)
-        except ValueError, e:
+            data = json.loads(request.body)
+        except ValueError as e:
             msg = _("malformed json data: %s") % unicode(e)
             return build_error_response(request, 400, msg)
 
