@@ -1,23 +1,22 @@
 # -*- coding: utf-8 -*-
 
-# Copyright 2012-2013 Universidad Politécnica de Madrid
+# Copyright (c) 2012-2014 CoNWeT Lab., Universidad Politécnica de Madrid
 
 # This file is part of Wirecloud.
 
 # Wirecloud is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
+# it under the terms of the GNU Affero General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 
 # Wirecloud is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Affero General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
-
 import errno
 import json
 from cStringIO import StringIO
@@ -35,34 +34,49 @@ from django.views.static import serve
 
 from wirecloud.catalogue.models import CatalogueResource
 import wirecloud.catalogue.utils as catalogue_utils
-from wirecloud.catalogue.views import iframe_error
 from wirecloud.commons.baseviews import Resource
-from wirecloud.commons.utils import downloader
-from wirecloud.commons.utils.http import authentication_required, build_error_response, get_content_type, supported_request_mime_types
+from wirecloud.commons.utils.downloader import download_http_content
+from wirecloud.commons.utils.http import authentication_required, authentication_required_cond, build_error_response, get_content_type, supported_request_mime_types, supported_response_mime_types
 from wirecloud.commons.utils.template import TemplateParseException
 from wirecloud.commons.utils.transaction import commit_on_http_success
 from wirecloud.commons.utils.wgt import InvalidContents, WgtFile
-from wirecloud.platform.markets.utils import get_market_managers
-from wirecloud.platform.models import Widget, IWidget
 from wirecloud.platform.localcatalogue.signals import resource_uninstalled
 from wirecloud.platform.localcatalogue.utils import install_resource_to_user
+from wirecloud.platform.markets.utils import get_market_managers
+from wirecloud.platform.models import Widget, IWidget, Workspace
+from wirecloud.platform.settings import ALLOW_ANONYMOUS_ACCESS
+
+
+def get_iwidgets_to_remove(resource, user):
+
+    query = Widget.objects.filter(resource=resource)
+    if query.exists():
+
+        widget = query.get()
+
+        # Remove all iwidgets that matches the resource
+        return IWidget.objects.filter(widget=widget, tab__workspace__creator=user)
+    else:
+        return ()
 
 
 class ResourceCollection(Resource):
 
     @authentication_required
+    @supported_response_mime_types(('application/json',))
     def read(self, request):
 
         resources = {}
-        for resource in CatalogueResource.objects.filter(Q(public=True) | Q(users=request.user) | Q(groups=request.user.groups.all())):
-            options = resource.get_processed_info(request)
-            resources[resource.local_uri_part] = options
+        if request.user.is_authenticated():
+            for resource in CatalogueResource.objects.filter(Q(public=True) | Q(users=request.user) | Q(groups=request.user.groups.all())):
+                options = resource.get_processed_info(request)
+                resources[resource.local_uri_part] = options
 
-        return HttpResponse(json.dumps(resources), mimetype='application/json; chatset=UTF-8')
+        return HttpResponse(json.dumps(resources), content_type='application/json; chatset=UTF-8')
 
     @authentication_required
-    @iframe_error
     @supported_request_mime_types(('application/x-www-form-urlencoded', 'application/json', 'multipart/form-data', 'application/octet-stream'))
+    @supported_response_mime_types(('application/json',))
     @commit_on_http_success
     def create(self, request):
 
@@ -85,7 +99,7 @@ class ResourceCollection(Resource):
         elif content_type == 'application/octet-stream':
 
             packaged = True
-            downloaded_file = StringIO(request.raw_post_data)
+            downloaded_file = StringIO(request.body)
             try:
                 file_contents = WgtFile(downloaded_file)
             except:
@@ -96,8 +110,8 @@ class ResourceCollection(Resource):
 
             if content_type == 'application/json':
                 try:
-                    data = json.loads(request.raw_post_data)
-                except ValueError, e:
+                    data = json.loads(request.body)
+                except ValueError as e:
                     msg = _("malformed json data: %s") % unicode(e)
                     return build_error_response(request, 400, msg)
 
@@ -120,14 +134,18 @@ class ResourceCollection(Resource):
                     msg = _('Missing market name')
                     return build_error_response(request, 400, msg)
 
+                market_id = market_endpoint['name']
                 market_managers = get_market_managers(request.user)
-                market_manager = market_managers[market_endpoint['name']]
+                if market_id not in market_managers:
+                    return build_error_response(request, 409, _('Unknown market: %s') % market_id)
+
+                market_manager = market_managers[market_id]
                 downloaded_file = market_manager.download_resource(request.user, templateURL, market_endpoint)
 
             else:
 
                 try:
-                    downloaded_file = downloader.download_http_content(templateURL)
+                    downloaded_file = download_http_content(templateURL)
                 except:
                     return build_error_response(request, 409, _('Content cannot be downloaded'))
 
@@ -137,7 +155,7 @@ class ResourceCollection(Resource):
                     downloaded_file = StringIO(downloaded_file)
                     file_contents = WgtFile(downloaded_file)
 
-                except zipfile.BadZipfile, e:
+                except zipfile.BadZipfile as e:
 
                     return build_error_response(request, 400, unicode(e))
 
@@ -148,14 +166,23 @@ class ResourceCollection(Resource):
 
             resource = install_resource_to_user(request.user, file_contents=file_contents, templateURL=templateURL, packaged=packaged, raise_conflicts=force_create)
 
-        except OSError, e:
+        except OSError as e:
 
             if e.errno == errno.EACCES:
                 return build_error_response(request, 500, _('Error writing the resource into the filesystem. Please, contact the server administrator.'))
             else:
                 raise
 
-        except (TemplateParseException, InvalidContents), e:
+        except TemplateParseException as e:
+
+            if packaged:
+                msg = "Error parsing config.xml descriptor file: %s" % e
+            else:
+                msg = "Error parsing resource descriptor from the providen URL: %s" % e
+
+            return build_error_response(request, 400, msg)
+
+        except InvalidContents as e:
 
             return build_error_response(request, 400, unicode(e))
 
@@ -163,7 +190,7 @@ class ResourceCollection(Resource):
 
             return build_error_response(request, 409, _('Resource already exists'))
 
-        return HttpResponse(json.dumps(resource.get_processed_info(request)), status=201, mimetype='application/json; charset=UTF-8')
+        return HttpResponse(json.dumps(resource.get_processed_info(request)), status=201, content_type='application/json; charset=UTF-8')
 
 
 class ResourceEntry(Resource):
@@ -173,7 +200,7 @@ class ResourceEntry(Resource):
 
         resource = get_object_or_404(CatalogueResource, vendor=vendor, short_name=name, version=version)
         if not request.user.is_superuser and not resource.is_available_for(request.user):
-            return HttpResponse(status=403)
+            return build_error_response(request, 403, _('You are not allowed to retrieve info about this resource'))
 
         file_name = '_'.join((vendor, name, version)) + '.wgt'
         base_dir = catalogue_utils.wgt_deployer.get_base_dir(vendor, name, version)
@@ -200,27 +227,28 @@ class ResourceEntry(Resource):
 
         resource_uninstalled.send(sender=resource, user=request.user)
 
-        if resource.public == False and resource.users.count() == 0 and resource.groups.count() == 0:
+        result = None
+        iwidgets_to_remove = None
+
+        if resource.resource_type() == 'widget' and request.GET.get('affected', 'false').lower() == 'true':
+            iwidgets_to_remove = get_iwidgets_to_remove(resource, request.user)
+            result = {'removedIWidgets': [iwidget.id for iwidget in iwidgets_to_remove]}
+
+        if resource.public is False and resource.users.count() == 0 and resource.groups.count() == 0:
             resource.delete()
+        elif resource.resource_type() == 'widget':
 
-        if resource.resource_type() == 'widget':
-            result = {'removedIWidgets': []}
+            if iwidgets_to_remove is None:
+                iwidgets_to_remove = get_iwidgets_to_remove(resource, request.user)
 
-            query = Widget.objects.filter(resource=resource)
-            if query.exists():
+            # We need to iterate the iwidget list as currently only the individual delete method removes Workspace cache
+            for iwidget in iwidgets_to_remove:
+                iwidget.delete()
 
-                widget = query.get()
-
-                # Remove all iwidgets that matches the resource
-                iwidgets = IWidget.objects.filter(widget=widget, tab__workspace__creator=request.user)
-                for iwidget in iwidgets:
-                    result['removedIWidgets'].append(iwidget.id)
-                    iwidget.delete()
-
-            if request.GET.get('affected', 'false').lower() == 'true':
-                return HttpResponse(json.dumps(result), mimetype='application/json; charset=UTF-8')
-
-        return HttpResponse(status=204)
+        if result is not None:
+            return HttpResponse(json.dumps(result), content_type='application/json; charset=UTF-8')
+        else:
+            return HttpResponse(status=204)
 
 
 class ResourceDescriptionEntry(Resource):
@@ -230,7 +258,7 @@ class ResourceDescriptionEntry(Resource):
 
         resource = get_object_or_404(CatalogueResource, vendor=vendor, short_name=name, version=version)
         if not request.user.is_superuser and not resource.is_available_for(request.user):
-            return HttpResponse(status=403)
+            return build_error_response(request, 403, _('You are not allowed to retrieve info about this resource'))
 
         resource_info = resource.get_processed_info(request)
         if request.GET.get('include_wgt_files', '').lower() == 'true':
@@ -242,4 +270,34 @@ class ResourceDescriptionEntry(Resource):
             else:
                 resource_info['wgt_files'] = ()
 
-        return HttpResponse(json.dumps(resource_info), mimetype='application/json; charset=UTF-8')
+        return HttpResponse(json.dumps(resource_info), content_type='application/json; charset=UTF-8')
+
+
+class WorkspaceResourceCollection(Resource):
+
+    @authentication_required_cond(ALLOW_ANONYMOUS_ACCESS)
+    def read(self, request, workspace_id):
+
+        workspace = get_object_or_404(Workspace, id=workspace_id)
+        if not workspace.public and not request.user.is_superuser and workspace.creator != request.user:
+            return build_error_response(request, 403, _("You don't have access to this workspace"))
+
+        resources = set()
+        for tab in workspace.tab_set.all():
+            for iwidget in tab.iwidget_set.select_related('widget__resource').all():
+                resources.add(iwidget.widget.resource)
+
+        wiring_status = json.loads(workspace.wiringStatus)
+        for operator_id, operator in wiring_status['operators'].iteritems():
+            vendor, name, version = operator['name'].split('/')
+            try:
+                resources.add(CatalogueResource.objects.get(vendor=vendor, short_name=name, version=version))
+            except CatalogueResource.DoesNotExist:
+                pass
+
+        result = {}
+        for resource in resources:
+            options = resource.get_processed_info(request)
+            result[resource.local_uri_part] = options
+
+        return HttpResponse(json.dumps(result), content_type='application/json; chatset=UTF-8')
