@@ -1,5 +1,5 @@
 /*
- *     Copyright (c) 2012-2013 CoNWeT Lab., Universidad Politécnica de Madrid
+ *     Copyright (c) 2012-2014 CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -25,7 +25,7 @@
 
     "use strict";
 
-    var platform, id, idx, tmp, i, current;
+    var platform, id, idx, tmp, i, current, ioperator;
 
     platform = window.parent;
 
@@ -46,7 +46,8 @@
     Object.defineProperty(window, 'MashupPlatform', {value: {}});
 
     // Temporal reference to the resource (in this case a widget) so other API files can make use of it. This attribute is removed in WirecloudAPIClosure.js
-    MashupPlatform.resource = platform.opManager.activeWorkspace.wiring.ioperators[id];
+    ioperator = platform.Wirecloud.activeWorkspace.wiring.ioperators[id];
+    MashupPlatform.resource = ioperator;
 
     // HTTP module
     Object.defineProperty(window.MashupPlatform, 'http', {value: {}});
@@ -57,25 +58,11 @@
     // Operator Module
     Object.defineProperty(window.MashupPlatform, 'operator', {value: {}});
     Object.defineProperty(window.MashupPlatform.operator, 'id', {value: id});
+    Object.defineProperty(window.MashupPlatform.operator, 'log', {
+        value: function log(msg, level) {
+            ioperator.logManager.log(msg, level);
+        }
+    });
     Object.preventExtensions(window.MashupPlatform.operator);
 
-    // Pref Module
-    Object.defineProperty(window.MashupPlatform, 'prefs', {value: {}});
-    Object.defineProperty(window.MashupPlatform.prefs, 'get', {
-        value: function get(key) {
-            return platform.opManager.activeWorkspace.wiring.getOperatorPrefValue(id, key);
-        }
-    });
-    Object.defineProperty(window.MashupPlatform.prefs, 'registerCallback', {
-        value: function registerCallback(callback) {
-            platform.opManager.activeWorkspace.wiring.registerOperatorPrefCallback(id, callback);
-        }
-    });
-    Object.defineProperty(window.MashupPlatform.prefs, 'set', {
-        value: function get(key, value) {
-            platform.opManager.activeWorkspace.wiring.setOperatorPrefValue(id, key, value);
-        }
-    });
-    Object.preventExtensions(window.MashupPlatform.prefs);
-
 })();
