@@ -1,5 +1,5 @@
 /*
- *     Copyright (c) 2012-2013 CoNWeT Lab., Universidad Politécnica de Madrid
+ *     Copyright (c) 2012-2014 CoNWeT Lab., Universidad Politécnica de Madrid
  *
  *     This file is part of Wirecloud Platform.
  *
@@ -19,7 +19,7 @@
  *
  */
 
-/*global gettext, interpolate, UserPref, Wirecloud*/
+/*global gettext, interpolate, Wirecloud*/
 
 (function () {
 
@@ -27,7 +27,7 @@
 
     var Widget = function Widget(data) {
 
-        var i, preference;
+        var i, preference, property;
 
         this.vendor = data.vendor;
         this.name = data.name;
@@ -35,22 +35,35 @@
         this.uri = this.vendor + '/' + this.name + '/' + this.version.text;
         this.id = this.uri;
 
-        this.display_name = data.display_name;
+        this.title = data.title;
         this.code_url = Wirecloud.URLs.WIDGET_CODE_ENTRY.evaluate({
             vendor: this.vendor,
             name: this.name,
             version: this.version.text
-        });
+        }) + "?v=" + Wirecloud.contextManager.get('version_hash');
         this.code_content_type = data.code_content_type;
 
         // Preferences
         this.preferences = {};
         this.preferenceList = [];
         for (i = 0; i < data.preferences.length; i++) {
-            preference = new UserPref(data.preferences[i].name, data.preferences[i].type, data.preferences[i]);
-            this.preferences[preference.varName] = preference;
+            preference = new Wirecloud.UserPrefDef(data.preferences[i].name, data.preferences[i].type, data.preferences[i]);
+            this.preferences[preference.name] = preference;
             this.preferenceList.push(preference);
         }
+        Object.freeze(this.preferences);
+        Object.freeze(this.preferenceList);
+
+        // Properties
+        this.properties = {}
+        this.propertyList = [];
+        for (i = 0; i < data.properties.length; i++) {
+            property = new Wirecloud.PersistentVariableDef(data.properties[i].name, data.properties[i].type, data.properties[i]);
+            this.properties[property.name] = property;
+            this.propertyList.push(property);
+        }
+        Object.freeze(this.properties);
+        Object.freeze(this.propertyList);
 
         // Inputs
         this.inputList = data.wiring.inputs;
@@ -70,9 +83,9 @@
         this.default_height = data.widget_height;
 
         /* FIXME */
-        this.getUriWiki = function getUriWiki() { return data.doc_uri; };
-        this.getImage = function getImage() { return data.image_uri; };
-        this.getIcon = function getIcon() { return data.iphone_image_uri !== '' ? data.iphone_image_uri : data.image_uri; };
+        this.getUriWiki = function getUriWiki() { return data.doc; };
+        this.getImage = function getImage() { return data.image; };
+        this.getIcon = function getIcon() { return data.smartphoneimage !== '' ? data.smartphoneimage : data.image; };
         this.getIPhoneImageURI = this.getIcon;
 
         var lastVersion = this.version;
@@ -108,41 +121,6 @@
         };
 
         this.isUpToDate = function isUpToDate() { return upToDate; };
-
-        this.variables = {};
-
-        var varname, variable;
-
-        for (i = 0; i < data.wiring.inputs.length; i += 1) {
-            this.variables[data.wiring.inputs[i].name] = data.wiring.inputs[i];
-            this.variables[data.wiring.inputs[i].name].aspect = 'SLOT';
-        }
-
-        for (i = 0; i < data.wiring.outputs.length; i += 1) {
-            this.variables[data.wiring.outputs[i].name] = data.wiring.outputs[i];
-            this.variables[data.wiring.outputs[i].name].aspect = 'EVEN';
-        }
-
-        for (i = 0; i < data.preferences.length; i += 1) {
-            this.variables[data.preferences[i].name] = data.preferences[i];
-            this.variables[data.preferences[i].name].aspect = 'PREF';
-        }
-
-        for (i = 0; i < data.properties.length; i += 1) {
-            this.variables[data.properties[i].name] = data.properties[i];
-            this.variables[data.properties[i].name].aspect = 'PROP';
-        }
-
-        for (i = 0; i < data.context.length; i += 1) {
-            this.variables[data.context[i].name] = data.context[i];
-        }
-
-        for (varname in this.variables) {
-            variable = this.variables[varname];
-            if (typeof variable.label === 'undefined' || variable.label === null || variable.label === '') {
-                variable.label = variable.name;
-            }
-        }
         /* END FIXME */
 
         Object.freeze(this);
