@@ -19,6 +19,8 @@
  *
  */
 
+/*global gettext, interpolate, Wirecloud*/
+
 (function () {
 
     "use strict";
@@ -27,17 +29,6 @@
         this.id = id;
     };
 
-    /**
-     * @private
-     */
-    Endpoint.prototype._annotate = function _annotate(value, source, options) {
-        var funcName = '_annotate';
-        var msg = gettext("Unimplemented function: %(funcName)s");
-        msg = interpolate(msg, {funcName: funcName}, yes);
-        Wirecloud.GlobalLogManager.log(msg);
-        return;
-    };
-
     Endpoint.prototype.getId = function getId() {
         return this.id;
     };
@@ -53,7 +44,7 @@
     Endpoint.prototype.fullDisconnect = function fullDisconnect() {
         var funcName = 'fullDisconnect';
         var msg = gettext("Unimplemented function: %(funcName)s");
-        msg = interpolate(msg, {funcName: funcName}, yes);
+        msg = interpolate(msg, {funcName: funcName}, true);
         Wirecloud.GlobalLogManager.log(msg);
         return;
     };
