@@ -1,34 +1,22 @@
 # -*- coding: utf-8 -*-
 
-#...............................licence...........................................
-#
-#     (C) Copyright 2008 Telefonica Investigacion y Desarrollo
-#     S.A.Unipersonal (Telefonica I+D)
-#
-#     This file is part of Morfeo EzWeb Platform.
-#
-#     Morfeo EzWeb Platform is free software: you can redistribute it and/or modify
-#     it under the terms of the GNU Affero General Public License as published by
-#     the Free Software Foundation, either version 3 of the License, or
-#     (at your option) any later version.
-#
-#     Morfeo EzWeb Platform is distributed in the hope that it will be useful,
-#     but WITHOUT ANY WARRANTY; without even the implied warranty of
-#     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#     GNU Affero General Public License for more details.
-#
-#     You should have received a copy of the GNU Affero General Public License
-#     along with Morfeo EzWeb Platform.  If not, see <http://www.gnu.org/licenses/>.
-#
-#     Info about members and contributors of the MORFEO project
-#     is available at
-#
-#     http://morfeo-project.org
-#
-#...............................licence...........................................#
+# Copyright (c) 2011-2014 CoNWeT Lab., Universidad Politécnica de Madrid
 
+# This file is part of Wirecloud.
+
+# Wirecloud is free software: you can redistribute it and/or modify
+# it under the terms of the GNU Affero General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+
+# Wirecloud is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Affero General Public License for more details.
+
+# You should have received a copy of the GNU Affero General Public License
+# along with Wirecloud.  If not, see <http://www.gnu.org/licenses/>.
 
-#
 import json
 import time
 import os
@@ -36,11 +24,9 @@ from urllib import url2pathname
 from urlparse import urljoin
 
 from django.conf import settings
-from django.contrib.auth.decorators import login_required
 from django.core.cache import cache
-from django.http import HttpResponse, HttpResponseForbidden, Http404
+from django.http import HttpResponse, Http404
 from django.shortcuts import get_object_or_404
-from django.utils.decorators import method_decorator
 from django.utils.encoding import smart_str
 from django.utils.translation import ugettext as _
 from django.views.decorators.http import require_GET
@@ -48,11 +34,9 @@ from django.views.static import serve
 
 from wirecloud.catalogue.models import CatalogueResource
 from wirecloud.commons.baseviews import Resource
-from wirecloud.commons.exceptions import Http403
-from wirecloud.commons.utils import downloader
 from wirecloud.commons.utils.cache import patch_cache_headers
-from wirecloud.commons.utils.http import build_error_response, get_absolute_reverse_url, get_current_domain, get_xml_error_response
-from wirecloud.platform.iwidget.utils import deleteIWidget
+from wirecloud.commons.utils.downloader import download_http_content, download_local_file
+from wirecloud.commons.utils.http import build_error_response, get_absolute_reverse_url, get_current_domain
 from wirecloud.platform.models import Widget, IWidget
 import wirecloud.platform.widget.utils as showcase_utils
 from wirecloud.platform.widget.utils import fix_widget_code
@@ -71,7 +55,7 @@ def deleteWidget(user, name, vendor, version):
         iwidgets = IWidget.objects.filter(widget=widget)
         for iwidget in iwidgets:
             result['removedIWidgets'].append(iwidget.id)
-            deleteIWidget(iwidget, user)
+            iwidget.delete()
 
         widget.delete()
 
@@ -81,27 +65,33 @@ def deleteWidget(user, name, vendor, version):
     return result
 
 
+def process_requirements(requirements):
+
+    return dict((requirement['name'], {}) for requirement in requirements)
+
+
 class WidgetCodeEntry(Resource):
 
-    @method_decorator(login_required)
     def read(self, request, vendor, name, version):
 
         resource = get_object_or_404(CatalogueResource.objects.select_related('widget__xhtml'), vendor=vendor, short_name=name, version=version)
-        if not resource.is_available_for(request.user):
-            raise Http403()
+        # For now, all widgets are freely accessible/distributable
+        #if not resource.is_available_for(request.user):
+        #    return build_error_response(request, 403, "Forbidden")
 
         if resource.resource_type() != 'widget':
             raise Http404()
 
+        mode = request.GET.get('mode', 'classic')
         widget_info = json.loads(resource.json_description)
 
         # check if the xhtml code has been cached
         if widget_info['code_cacheable'] is True:
 
-            cache_key = resource.widget.xhtml.get_cache_key(get_current_domain(request))
+            cache_key = resource.widget.xhtml.get_cache_key(get_current_domain(request), mode)
             cache_entry = cache.get(cache_key)
             if cache_entry is not None:
-                response = HttpResponse(cache_entry['code'], mimetype=cache_entry['mimetype'])
+                response = HttpResponse(cache_entry['code'], content_type=cache_entry['content_type'])
                 patch_cache_headers(response, cache_entry['timestamp'], cache_entry['timeout'])
                 return response
 
@@ -113,20 +103,23 @@ class WidgetCodeEntry(Resource):
         force_base = False
         base_url = xhtml.url
         if not base_url.startswith(('http://', 'https://')):
-            base_url = get_absolute_reverse_url('wirecloud_showcase.media', args=(base_url.split('/', 4)), request=request)
+            base_url = get_absolute_reverse_url('wirecloud.showcase_media', args=(base_url.split('/', 4)), request=request)
             force_base = True
 
         code = xhtml.code
         if not xhtml.cacheable or code == '':
             try:
                 if xhtml.url.startswith(('http://', 'https://')):
-                    code = downloader.download_http_content(urljoin(base_url, xhtml.url), user=request.user)
+                    code = download_http_content(urljoin(base_url, xhtml.url), user=request.user)
                 else:
-                    code = downloader.download_http_content('file://' + os.path.join(showcase_utils.wgt_deployer.root_dir, url2pathname(xhtml.url)), user=request.user)
+                    code = download_local_file(os.path.join(showcase_utils.wgt_deployer.root_dir, url2pathname(xhtml.url)))
 
-            except Exception, e:
+            except Exception as e:
                 msg = _("XHTML code is not accessible: %(errorMsg)s") % {'errorMsg': e.message}
                 return build_error_response(request, 502, msg)
+        else:
+            # Code contents comes as unicode from persistence, we need bytes
+            code = code.encode(charset)
 
         if xhtml.cacheable and (xhtml.code == '' or xhtml.code_timestamp is None):
             xhtml.code = code.decode(charset)
@@ -138,7 +131,7 @@ class WidgetCodeEntry(Resource):
             xhtml.save()
 
         try:
-            code = fix_widget_code(code, base_url, content_type, request, charset, xhtml.use_platform_style, force_base=force_base)
+            code = fix_widget_code(code, base_url, content_type, request, charset, xhtml.use_platform_style, process_requirements(widget_info['requirements']), force_base, mode)
         except UnicodeEncodeError:
             msg = _('Widget code was not encoded using the specified charset (%(charset)s according to the widget descriptor file).')
             return build_error_response(request, 502, msg % {'charset': charset})
@@ -147,7 +140,7 @@ class WidgetCodeEntry(Resource):
             cache_timeout = 31536000  # 1 year
             cache_entry = {
                 'code': code,
-                'mimetype': '%s; charset=%s' % (content_type, charset),
+                'content_type': '%s; charset=%s' % (content_type, charset),
                 'timestamp': xhtml.code_timestamp,
                 'timeout': cache_timeout,
             }
@@ -155,7 +148,7 @@ class WidgetCodeEntry(Resource):
         else:
             cache_timeout = 0
 
-        response = HttpResponse(code, mimetype='%s; charset=%s' % (content_type, charset))
+        response = HttpResponse(code, content_type='%s; charset=%s' % (content_type, charset))
         patch_cache_headers(response, xhtml.code_timestamp, cache_timeout)
         return response
 
@@ -164,8 +157,9 @@ class WidgetCodeEntry(Resource):
 def serve_showcase_media(request, vendor, name, version, file_path):
 
     resource = get_object_or_404(CatalogueResource, vendor=vendor, short_name=name, version=version)
-    if not resource.is_available_for(request.user):
-        return HttpResponseForbidden()
+    # For now, all widgets are freely accessible/distributable
+    #if not resource.is_available_for(request.user):
+    #    return build_error_response(request, 403, "Forbidden")
 
     base_dir = showcase_utils.wgt_deployer.get_base_dir(vendor, name, version)
     local_path = os.path.join(base_dir, url2pathname(file_path))
